@@ -32,17 +32,22 @@
 UnCompressView::UnCompressView(QWidget *parent)
     : DataTreeView(parent)
 {
+    qDebug() << "UnCompressView constructor called";
     initUI();
     initConnections();
+    qDebug() << "UnCompressView initialized";
 }
 
 UnCompressView::~UnCompressView()
 {
+    qDebug() << "UnCompressView destructor called";
     clearDragData();
+    qDebug() << "UnCompressView destroyed";
 }
 
 void UnCompressView::refreshArchiveData()
 {
+    qDebug() << "Refreshing archive data";
     ArchiveData &stArchiveData =  DataManager::get_instance().archiveData();
 
     // 刷新第一层级文件夹子项的数目
@@ -56,6 +61,7 @@ void UnCompressView::refreshArchiveData()
     m_pModel->refreshFileEntry(stArchiveData.listRootEntry);
     m_mapShowEntry["/"] = stArchiveData.listRootEntry;
 
+    qInfo() << "Archive data refreshed successfully";
     // 重置排序
     m_pHeaderView->setSortIndicator(-1, Qt::SortOrder::AscendingOrder);
     sortByColumn(DC_Name, Qt::AscendingOrder);
@@ -75,6 +81,7 @@ void UnCompressView::setDefaultUncompressPath(const QString &strPath)
 
 void UnCompressView::mousePressEvent(QMouseEvent *event)
 {
+    qDebug() << "Mouse press event at position:" << event->pos();
     if (event->button() == Qt::MouseButton::LeftButton) {
         m_dragPos = event->pos();
     }
@@ -200,6 +207,7 @@ void UnCompressView::clearDragData()
 
 void UnCompressView::mouseDoubleClickEvent(QMouseEvent *event)
 {
+    qDebug() << "Mouse double click event at position:" << event->pos();
     if (event->button() == Qt::MouseButton::LeftButton) {
         handleDoubleClick(indexAt(event->pos()));   // 双击处理
     }
@@ -555,6 +563,7 @@ QList<FileEntry> UnCompressView::getSelEntry()
 
 void UnCompressView::extract2Path(const QString &strPath)
 {
+    qDebug() << "Extracting files to path:" << strPath;
     QList<FileEntry> listSelEntry = getSelEntry();    // 待提取的文件数据
     ExtractionOptions stOptions;    // 提取参数
     stOptions.strTargetPath = strPath;
@@ -570,6 +579,8 @@ void UnCompressView::extract2Path(const QString &strPath)
         }
     }
 
+    qInfo() << "Extraction prepared, files count:" << listSelEntry.size()
+            << ", total size:" << stOptions.qSize << "bytes";
     // 发送提取信号
     emit signalExtract2Path(listSelEntry, stOptions);
 }
@@ -683,6 +694,7 @@ void UnCompressView::slotExtract2Here()
 
 void UnCompressView::slotDeleteFile()
 {
+    qDebug() << "Delete file operation initiated";
     QVariantMap mapdata = mapOrderJson();
     if(mapdata.contains(ORDER_DELETE)) {
         if(!mapdata.value(ORDER_DELETE).toBool()) return;
@@ -707,6 +719,7 @@ void UnCompressView::slotDeleteFile()
                 }
             }
 
+            qInfo() << "Deleting" << listSelEntry.size() << "files, total size:" << qSize << "bytes";
             // 发送删除信号
             m_eChangeType = CT_Delete;
             emit signalDelFiles(listSelEntry, qSize);
