@@ -418,7 +418,12 @@ TEST_F(UT_Cli7zPlugin, test_readListLine_018)
     m_tester->m_parseState = ParseStateEntryInformation;
     m_tester->m_archiveType = Cli7zPlugin::ArchiveType::ArchiveType7z;
     EXPECT_EQ(m_tester->readListLine("Modified = 2021-06-18 15:27:01"), true);
-    EXPECT_EQ(m_tester->m_fileEntry.uLastModifiedTime, QDateTime::fromString("2021-06-18 15:27:01", "yyyy-MM-dd hh:mm:ss").toTime_t());
+    EXPECT_EQ(m_tester->m_fileEntry.uLastModifiedTime, QDateTime::fromString("2021-06-18 15:27:01", "yyyy-MM-dd hh:mm:ss")
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    .toTime_t());
+#else
+    .toSecsSinceEpoch());
+#endif
 }
 
 TEST_F(UT_Cli7zPlugin, test_readListLine_019)
@@ -779,15 +784,15 @@ TEST_F(UT_Cli7zPlugin, test_runProcess_001)
 
 TEST_F(UT_Cli7zPlugin, test_runProcess_002)
 {
-//    Stub stub;
-//    stub.set(ADDR(QStandardPaths, findExecutable), qStandardPaths_findExecutable_stub);
-//    stub.set(ADDR(QProcess, waitForStarted), qProcess_waitForStarted_stub);
-//    g_QProcess_waitForStarted_result = true;
-//    m_tester->m_workStatus = WT_Extract;
-//    m_tester->m_isTar7z = true;
-//    EXPECT_EQ(m_tester->runProcess("7z", QStringList()), true);
-//    EXPECT_EQ(m_tester->m_stdOutData.isEmpty(), true);
-//    EXPECT_EQ(m_tester->m_isProcessKilled, false);
+    Stub stub;
+    stub.set(ADDR(QStandardPaths, findExecutable), qStandardPaths_findExecutable_stub);
+    stub.set(ADDR(QProcess, waitForStarted), qProcess_waitForStarted_stub);
+    g_QProcess_waitForStarted_result = true;
+    m_tester->m_workStatus = WT_Extract;
+    m_tester->m_isTar7z = true;
+    EXPECT_EQ(m_tester->runProcess("7z", QStringList()), true);
+    EXPECT_EQ(m_tester->m_stdOutData.isEmpty(), true);
+    EXPECT_EQ(m_tester->m_isProcessKilled, false);
 }
 
 TEST_F(UT_Cli7zPlugin, test_runProcess_003)
