@@ -313,11 +313,11 @@ TEST_F(UT_MainWindow, test_loadArchive_001)
 
 TEST_F(UT_MainWindow, test_loadArchive_002)
 {
-//    Stub stub;
-//    QFileInfoStub::stub_QFileInfo_isReadable(stub, true);
-//    QFileInfoStub::stub_QFileInfo_exists(stub, false);
-//    m_tester->loadArchive("1.zip");
-//    EXPECT_EQ(m_tester->m_ePageID == PI_Failure, true);
+    Stub stub;
+    QFileInfoStub::stub_QFileInfo_isReadable(stub, true);
+    QFileInfoStub::stub_QFileInfo_exists(stub, false);
+    m_tester->loadArchive("1.zip");
+    EXPECT_EQ(m_tester->m_ePageID == PI_Failure, true);
 }
 
 TEST_F(UT_MainWindow, test_loadArchive_003)
@@ -351,16 +351,16 @@ TEST_F(UT_MainWindow, test_timerEvent_001)
 
 TEST_F(UT_MainWindow, test_timerEvent_002)
 {
-//    Stub stub;
-//    CustomDialogStub::stub_TipDialog_showDialog(stub, 0);
-//    stub.set(ADDR(CompressPage, compressFiles), compressPage_compressFiles_stub);
-//    QFileInfoStub::stub_QFileInfo_exists(stub, false);
+    Stub stub;
+    CustomDialogStub::stub_TipDialog_showDialog(stub, 0);
+    stub.set(ADDR(CompressPage, compressFiles), compressPage_compressFiles_stub);
+    QFileInfoStub::stub_QFileInfo_exists(stub, false);
 
-//    QTimerEvent *event = new QTimerEvent(m_tester->m_iCompressedWatchTimerID);
-//    m_tester->timerEvent(event);
-//    delete event;
-//    EXPECT_EQ(m_tester->m_initFlag, false);
-//    EXPECT_EQ(m_tester->m_ePageID, PI_Compress);
+    QTimerEvent *event = new QTimerEvent(m_tester->m_iCompressedWatchTimerID);
+    m_tester->timerEvent(event);
+    delete event;
+    EXPECT_EQ(m_tester->m_initFlag, false);
+    EXPECT_EQ(m_tester->m_ePageID, PI_Compress);
 }
 
 TEST_F(UT_MainWindow, test_timerEvent_003)
@@ -435,12 +435,12 @@ TEST_F(UT_MainWindow, test_checkSettings_003)
 
 TEST_F(UT_MainWindow, test_checkSettings_004)
 {
-//    Stub stub;
-//    CustomDialogStub::stub_TipDialog_showDialog(stub, 0);
-//    QFileInfoStub::stub_QFileInfo_exists(stub, true);
-//    QFileInfoStub::stub_QFileInfo_isReadable(stub, true);
-//    QFileInfoStub::stub_QFileInfo_isDir(stub, false);
-//    EXPECT_EQ(m_tester->checkSettings(""), true);
+    Stub stub;
+    CustomDialogStub::stub_TipDialog_showDialog(stub, 0);
+    QFileInfoStub::stub_QFileInfo_exists(stub, true);
+    QFileInfoStub::stub_QFileInfo_isReadable(stub, true);
+    QFileInfoStub::stub_QFileInfo_isDir(stub, false);
+    EXPECT_EQ(m_tester->checkSettings(""), true);
 }
 
 CustomMimeType determineMimeType_stub(const QString &)
@@ -1157,16 +1157,16 @@ TEST_F(UT_MainWindow, test_handleJobNormalFinished_0010)
 
 TEST_F(UT_MainWindow, test_handleJobNormalFinished_0011)
 {
-//    Stub stub;
-//    CommonStub::stub_QThread_start(stub);
-//    stub.set(ADDR(SettingDialog, isAutoDeleteFile), settingDialog_isAutoDeleteFile_stub);
-//    ArchiveManagerStub::stub_ArchiveManager_updateArchiveComment(stub, true);
-//    ArchiveManagerStub::stub_ArchiveManager_updateArchiveCacheData(stub, true);
-//    CustomDialogStub::stub_TipDialog_showDialog(stub, 0);
-//    CustomDialogStub::stub_SimpleQueryDialog_showDialog(stub, 0);
+    Stub stub;
+    CommonStub::stub_QThread_start(stub);
+    stub.set(ADDR(SettingDialog, isAutoDeleteFile), settingDialog_isAutoDeleteFile_stub);
+    ArchiveManagerStub::stub_ArchiveManager_updateArchiveComment(stub, true);
+    ArchiveManagerStub::stub_ArchiveManager_updateArchiveCacheData(stub, true);
+    CustomDialogStub::stub_TipDialog_showDialog(stub, 0);
+    CustomDialogStub::stub_SimpleQueryDialog_showDialog(stub, 0);
 
-//    m_tester->handleJobNormalFinished(ArchiveJob::JT_Convert);
-//    EXPECT_EQ(m_tester->m_ePageID, PI_Success);
+    m_tester->handleJobNormalFinished(ArchiveJob::JT_Convert);
+    EXPECT_EQ(m_tester->m_ePageID, PI_Success);
 }
 
 TEST_F(UT_MainWindow, test_handleJobNormalFinished_0012)
@@ -1381,22 +1381,22 @@ TEST_F(UT_MainWindow, test_resetMainwindow)
 
 TEST_F(UT_MainWindow, test_deleteWhenJobFinish_001)
 {
-//    Stub stub;
-//    QFileInfoStub::stub_QFileInfo_exists(stub, true);
-//    QFileInfoStub::stub_QFileInfo_isDir(stub, true);
-//    m_tester->m_eStartupType = StartupType::ST_Compresstozip7z;
-//    m_tester->m_stCompressParameter.listCompressFiles << "1/";
-//    m_tester->deleteWhenJobFinish(ArchiveJob::JT_Create);
+    Stub stub;
+    QFileInfoStub::stub_QFileInfo_exists(stub, true);
+    QFileInfoStub::stub_QFileInfo_isDir(stub, true);
+    m_tester->m_eStartupType = StartupType::ST_Compresstozip7z;
+    m_tester->m_stCompressParameter.listCompressFiles << "1/";
+    m_tester->deleteWhenJobFinish(ArchiveJob::JT_Create);
 }
 
 TEST_F(UT_MainWindow, test_deleteWhenJobFinish_002)
 {
-//    Stub stub;
-//    QFileInfoStub::stub_QFileInfo_exists(stub, true);
-//    QFileInfoStub::stub_QFileInfo_isDir(stub, false);
-//    m_tester->m_eStartupType = StartupType::ST_Compresstozip7z;
-//    m_tester->m_stCompressParameter.listCompressFiles << "1.txt";
-//    m_tester->deleteWhenJobFinish(ArchiveJob::JT_Create);
+    Stub stub;
+    QFileInfoStub::stub_QFileInfo_exists(stub, true);
+    QFileInfoStub::stub_QFileInfo_isDir(stub, false);
+    m_tester->m_eStartupType = StartupType::ST_Compresstozip7z;
+    m_tester->m_stCompressParameter.listCompressFiles << "1.txt";
+    m_tester->deleteWhenJobFinish(ArchiveJob::JT_Create);
 }
 
 TEST_F(UT_MainWindow, test_deleteWhenJobFinish_003)
